imbalanced-learn documentation — Version 0.11.0.dev0

# imbalanced-learn documentation

Date: Jul 08, 2023 Version: 0.11.0.dev0

Useful links: Binary Installers | Source Repository | Issues & Ideas | Q&A Support

Imbalanced-learn (imported as `imblearn`) is an open source, MIT-licensed library relying on scikit-learn (imported as `sklearn`) and provides tools when dealing with classification with imbalanced classes.

##### Getting started

Check out the getting started guides to install imbalanced-learn. Some extra information to get started with a new contribution is also provided.

To the installation guideline

##### User guide

The user guide provides in-depth information on the key concepts of imbalanced-learn with useful background information and explanation.

To the user guide

##### API reference

The reference guide contains a detailed description of the imbalanced-learn API. To known more about methods parameters.

To the reference guide

##### Examples

The gallery of examples is a good place to see imbalanced-learn in action. Select an example and dive in.

To the gallery of examples

next

Getting Started